@@ -23,13 +23,13 @@ program marker
     call DclSetParm( 'ENABLE_CLIPPING', .true.)
     call DclDrawViewPortFrame(1)
 
-    call DclDrawMarker(x, y)                    ! <-- }[J[` (1)
-    call DclDrawMarker(x, y-0.1, type=2)        ! <-- }[J[` (2)
-    call DclDrawMarker(x, y-0.2, type=3)        ! <-- }[J[` (3)
-    call DclDrawMarker(x, y-0.3, type=2,height=0.06)! <-- }[J[` (4)
-    call DclDrawMarker(x, y-0.4, index=2)       ! <-- }[J[` (5)
-    call DclDrawMarker(x, y-0.5, index=3,type=2)! <-- }[J[` (6)
-    call DclDrawLine(x, y-0.5)                  ! <-- ܂`
+    call DclDrawMarker(x, y)                    ! <-- マーカー描画 (1列目)
+    call DclDrawMarker(x, y-0.1, type=2)        ! <-- マーカー描画 (2列目)
+    call DclDrawMarker(x, y-0.2, type=3)        ! <-- マーカー描画 (3列目)
+    call DclDrawMarker(x, y-0.3, type=2,height=0.06)! <-- マーカー描画 (4列目)
+    call DclDrawMarker(x, y-0.4, index=2)       ! <-- マーカー描画 (5列目)
+    call DclDrawMarker(x, y-0.5, index=3,type=2)! <-- マーカー描画 (6列目)
+    call DclDrawLine(x, y-0.5)                  ! <-- 折れ線描画
 
     call DclCloseGraphics
 
