@@ -9,11 +9,10 @@
 
       REAL      XBOX(NP), YBOX(NP)
       CHARACTER CHR*5
-      CHARACTER TITLE*20
 
       DATA      XBOX/ 0., 1., 1., 0. /
       DATA      YBOX/ 0., 0., 1., 1. /
-      
+
       WRITE(*,*) ' WORKSTATION ID (I) ? ; '
       CALL SGPWSN
       READ (*,*) IWS
@@ -25,12 +24,10 @@
       CALL SGLSET( 'LFULL' , .TRUE. )
       CALL SLRAT( 0.85, 1. )
       CALL SLMGN( 0., 0., 0.05, 0.1 )
-
+      CALL SLSTTL( 'TEST OF COLORMAP', 'T', 0., -0.5, 0.025, 1 )
 
       DO 20 K=1,80
 
-      WRITE(TITLE,'(A,I3)')'TEST OF COLORMAP ',K
-      CALL SLSTTL(TITLE , 'T', 0., -0.5, 0.025, 1 )
       CALL SWISET('ICLRMAP',K)
 *      IF (MOD(K,2).EQ.1) THEN
 *        CALL SWLSET('LFGBG',.FALSE.)
