@@ -70,7 +70,7 @@
       WRITE(CH,'(I3)') I+J*N
       CALL SGTXZV(X1, Y(I)+0.035, CH, 0.015, 0, -1, 1)
       CALL SGSTXS(0.05)
-      CALL SGTXV(XC, Y(I), 'ABCabs012αβγ')
+      CALL SGTXV(XC, Y(I), 'ABCabs012留硫粒')
       WRITE(*,*) FULLNAME
 
 
