@@ -28,7 +28,7 @@
       CALL SWSLCL(ICOLOR)
 
 
-      ITPATXI=IFCIDX*1000+MOD(ITPAT,1000)
+      ITPATX=IFCIDX*1000+MOD(ITPAT,1000)
       CALL SZTNOP(ITPATX)
       CALL SZTNZV(N,VPX,VPY)
       CALL SZTNCL
