@@ -42,7 +42,8 @@
           G(I,J)=P
           B(I,J)=Q
         ELSE
-          WRITE(*,*)"ERROR!HSV2RGB"
+          CALL MSGDMP('E','CLSVRG',
+     +          'CAN NOT CONVERT HSV TO RGB.')
         ENDIF
       ENDIF
  20   CONTINUE
