@@ -1,4 +1,6 @@
 #include "stdio.h"
+#include "stdlib.h"
+#include "string.h"
 
 #define min(a,b) ((a) <= (b) ? (a) : (b))
 
@@ -25,12 +27,10 @@ void exit_(integer *rc);
 /*     Copyright (C) 2000-2022 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 
-/*
-void msgdmp_(char *clev, char *csub, char *cmsg, 
-			      int clev_len, int csub_len, int cmsg_len){
-  printf("MSGDMP_\n");
-}
-*/
+void s_copy(char *, char *, ftnlen, ftnlen);
+void s_cat(char *, char **, integer *, integer *, ftnlen);
+int s_stop(char *s, ftnlen n);
+
 /* Subroutine */ int msgdmp_dclorig(char *clev, char *csub, char *cmsg, int 
 	clev_len, int csub_len, int cmsg_len)
 {
@@ -183,6 +183,25 @@ int set_msgdmp_err_func( int (*f)(char *csub, char *cmsg,
     msgdmp_func = msgdmp_err_replaceable;
 }
 
+//何故か残しておかないとruby−dclのビルドに失敗する
+//gem の 1.8.2 だけかも？
+int msgdmp__(char *clev, char *csub, char *cmsg, ftnlen 
+	clev_len, ftnlen csub_len, ftnlen cmsg_len)
+{
+    return( (*msgdmp_func)(clev, csub, cmsg, 
+	clev_len, csub_len, cmsg_len) );
+}
+
+
+int msgdmp_(char *clev, char *csub, char *cmsg, ftnlen 
+	clev_len, ftnlen csub_len, ftnlen cmsg_len)
+{
+    return( (*msgdmp_func)(clev, csub, cmsg, 
+	clev_len, csub_len, cmsg_len) );
+}
+
+
+
 static int msgdmp_err_replaceable(char *clev, char *csub, char *cmsg, int
 	clev_len, int csub_len, int cmsg_len)
      /* msgdmp_err_replaceable: by T Horinouchi 2001/11/30
@@ -198,9 +217,9 @@ static int msgdmp_err_replaceable(char *clev, char *csub, char *cmsg, int
     integer i__1, i__2[6], i__3[4];
 
     /* Builtin functions */
-    /* Subroutine */ void s_copy(char *, char *, ftnlen, ftnlen), s_cat(char *,
+    /* Subroutine */ /* void s_copy(char *, char *, ftnlen, ftnlen), s_cat(char *,
 	     char **, integer *, integer *, ftnlen);
-	     int s_stop(char *, ftnlen);
+	     int s_stop(char *, ftnlen); */
 
     /* Local variables */
     extern integer lenc_(char *, ftnlen);
