@@ -205,57 +205,57 @@ module dcl_parm
         do
           call udlqin(name,idx)
           if(idx.ne.0) then
-            call udlqvl(idx, DclGetReal) ;  exit
+            call udlqvl(idx, DclGetLogical) ;  exit
           end if
 
           call uelqin(name,idx)
           if(idx.ne.0) then
-            call uelqvl(idx, DclGetReal) ;  exit
+            call uelqvl(idx, DclGetLogical) ;  exit
           end if
 
           call uglqin(name,idx)
           if(idx.ne.0) then
-            call uglqvl(idx, DclGetReal) ;  exit
+            call uglqvl(idx, DclGetLogical) ;  exit
           end if
 
           call uslqin(name,idx)
           if(idx.ne.0) then
-            call uslqvl(idx, DclGetReal) ;  exit
+            call uslqvl(idx, DclGetLogical) ;  exit
           end if
 
           call uzlqin(name,idx)
           if(idx.ne.0) then
-            call uzlqvl(idx, DclGetReal) ;  exit
+            call uzlqvl(idx, DclGetLogical) ;  exit
           end if
 
           call ullqin(name,idx)
           if(idx.ne.0) then
-            call ullqvl(idx, DclGetReal) ;  exit
+            call ullqvl(idx, DclGetLogical) ;  exit
           end if
 
           call uclqin(name,idx)
           if(idx.ne.0) then
-            call uclqvl(idx, DclGetReal) ;  exit
+            call uclqvl(idx, DclGetLogical) ;  exit
           end if
 
           call umlqin(name,idx)
           if(idx.ne.0) then
-            call umlqvl(idx, DclGetReal) ;  exit
+            call umlqvl(idx, DclGetLogical) ;  exit
           end if
 
           call sglqin(name,idx)
           if(idx.ne.0) then
-            call sglqvl(idx, DclGetReal) ;  exit
+            call sglqvl(idx, DclGetLogical) ;  exit
           end if
 
           call swlqin(name,idx)
           if(idx.ne.0) then
-            call swlqvl(idx, DclGetReal) ;  exit
+            call swlqvl(idx, DclGetLogical) ;  exit
           end if
 
           call gllqin(name,idx)
           if(idx.ne.0) then
-            call gllqvl(idx, DclGetReal) ;  exit
+            call gllqvl(idx, DclGetLogical) ;  exit
           end if
           call msgdmp('E', 'DclGetParm', 'Invalid parameter ['//name//']')
         end do
