@@ -10,8 +10,8 @@ module intrlib
 
   contains
 
-    function DclInterpolateR(x)                !¿֤򤹤
-      real, intent(in), dimension(:)        :: x !¿
+    function DclInterpolateR(x)                !実数型配列の補間をする
+      real, intent(in), dimension(:)        :: x !処理する実数型の配列
       real,             dimension(size(x)) :: DclInterpolateReal
 
       call prcopn('DclInterpolateR')
@@ -20,8 +20,8 @@ module intrlib
       call prccls('DclInterpolateR')
     end function
       
-    function DclInterpolateC(x)            !ʣǿ֤򤹤
-      complex, intent(in), dimension(:)        :: x !ʣǿ
+    function DclInterpolateC(x)            !複素数型配列の補間をする
+      complex, intent(in), dimension(:)        :: x !処理する複素数型の配列
       complex,             dimension(size(x)) :: DclInterpolateComplex
 
       call prcopn('DclInterpolateC')
