@@ -161,12 +161,12 @@ module uspack
 
     end subroutine
 !----------------------------------
-!   UXYZPACK ɸ
-!---------------------------------- ȥ٥δֳ֤ꤷƺɸ
+!   UXYZPACK 座標軸
+!---------------------------------- 目盛とラベルの間隔を指定して座標軸を描く
     subroutine DclDrawAxis(side,dlabel,dtick, &
                          & title,unit,factor,offset,section) 
-      character(len=*), intent(in) :: side !ɸ
-      real, intent(in) :: dlabel, dtick    !ӥ٥δֳ
+      character(len=*), intent(in) :: side !座標軸を描く場所
+      real, intent(in) :: dlabel, dtick    !目盛およびラベルの間隔
       character(len=*), intent(in), optional :: title, unit
       real, intent(in), optional :: factor,offset,section
 
@@ -189,16 +189,16 @@ module uspack
       call sgocls('DclDrawAxis')
 
     end subroutine
-!---------------------------------- ȥ٥ξꤷƺɸ
+!---------------------------------- 目盛とラベルの場所を指定して座標軸を描く．
     subroutine DclDrawAxisSpecify(side,label_pos,tick_pos,label, &
                                 & title, unit, factor, offset, section)
-      character(len=*), intent(in) :: side       !ɸ
-      real, intent(in), dimension(:) :: label_pos       !礭ӥ٥ξ
-      real, intent(in), dimension(:), optional :: tick_pos      !ξ
-      character(len=*), intent(in), dimension(:), optional :: label !٥
+      character(len=*), intent(in) :: side       !座標軸を描く場所
+      real, intent(in), dimension(:) :: label_pos       !大きめの目盛およびラベルの場所
+      real, intent(in), dimension(:), optional :: tick_pos      !小さめの目盛の場所
+      character(len=*), intent(in), dimension(:), optional :: label !ラベル
       character(len=*), intent(in), optional :: title, unit
       real, intent(in), optional :: factor, offset, section
-      real, dimension(1) :: dummy      !ξ
+      real, dimension(1) :: dummy      !小さめの目盛の場所
 
 
       call sgoopn('DclDrawAxisSpecify', ' ')
@@ -232,10 +232,10 @@ module uspack
       call sgocls('DclDrawAxisSpecify')
 
     end subroutine
-!---------------------------------- LOG ɸ
+!---------------------------------- LOG 座標軸を描く．
     subroutine DclDrawAxisLog(side, nlabel, nticks, &
                             & title, unit, format, cformat, factor, section, label_pos)
-      character(len=*), intent(in)  :: side       !ɸ
+      character(len=*), intent(in)  :: side       !座標軸を描く場所
       integer, intent(in)           :: nlabel, nticks
       integer, intent(in), optional :: format
       character(len=*), intent(in), optional :: cformat
@@ -291,14 +291,14 @@ module uspack
 
     end subroutine
 !----------------------------------------
-!   պɸ
+!   日付座標軸
 !----------------------------------------
-    subroutine DclDrawAxisCalendar (side,first_day, title, unit, type,nd) !ǯ˴ؤɸ
-      character(len=*),  intent(in) :: side       !ɸ񤯾ꤹ
-      type(dcl_date),    intent(in) :: first_day   !uc0դꤹ
+    subroutine DclDrawAxisCalendar (side,first_day, title, unit, type,nd) !日・月・年に関する座標軸を描く．
+      character(len=*),  intent(in) :: side       !座標軸を書く場所を指定する
+      type(dcl_date),    intent(in) :: first_day   !ucで0に相当する場所の日付を指定する
       character(len=*), intent(in), optional :: title, unit
-      character(len=*),  intent(in), optional :: type        !ǯ YMD ǻꤹ
-      integer, optional, intent(in) :: nd          !褹ꤹ
+      character(len=*),  intent(in), optional :: type        !年、月、日を YMD で指定する
+      integer, optional, intent(in) :: nd          !作画する日数を指定する
       character(len=8)              :: type0
 
       call sgoopn('DclDrawAxisCalendar', ' ')
@@ -325,12 +325,12 @@ module uspack
     end subroutine
       
 !----------------------------------
-!   UXYZPACK ɸ
-!---------------------------------- ȥ
+!   UXYZPACK 座標軸要素
+!---------------------------------- タイトルを描く．
     subroutine DclDrawTitle(side,title,position,sw)
-      character(len=*), intent(in) :: side     !ɸꤹ
-      character(len=*), intent(in) :: title    !ȥ
-      real,   optional, intent(in) :: position !:-1+1δ֤μ¿
+      character(len=*), intent(in) :: side     !座標軸を描く場所を指定する
+      character(len=*), intent(in) :: title    !描くタイトル
+      real,   optional, intent(in) :: position !位置:-1から+1の間の実数値
       integer,optional, intent(in) :: sw
 
       call sgoopn('DclDrawTitle', ' ')
@@ -346,10 +346,10 @@ module uspack
       call uspttl(side, isw, title, pos) 
       call sgocls('DclDrawTitle')
     end subroutine
-!---------------------------------- 򼨤ʬ
+!---------------------------------- 軸を示す線分を描く．
     subroutine DclDrawAxisLine(side,sw)
-      character(len=*),  intent(in) :: side   !ɸꤹ
-      integer, optional, intent(in) :: sw     !°ꤹ
+      character(len=*),  intent(in) :: side   !座標軸を描く場所を指定する
+      integer, optional, intent(in) :: sw     !描く軸の属性を指定する
 
       call sgoopn('DclDrawAxisLine', ' ')
 
@@ -360,11 +360,11 @@ module uspack
       call uspaxs(side,isw)
       call sgocls('DclDrawAxisLine')
     end subroutine
-!---------------------------------- 
+!---------------------------------- 目盛を描く．
     subroutine DclDrawTickmark(side, position, sw)
-      character(len=*), intent(in)        :: side      !ɸξ
-      integer,   intent(in), optional     :: sw        !°
-      real,      intent(in), dimension(:) :: position  !
+      character(len=*), intent(in)        :: side      !目盛を描く座標軸の場所
+      integer,   intent(in), optional     :: sw        !描く目盛の属性
+      real,      intent(in), dimension(:) :: position  !目盛を描く場所
       integer                             :: isw
 
       call sgoopn('DclDrawTickmark', ' ')
@@ -375,12 +375,12 @@ module uspack
       call uxptmk(side, isw, position, size(position)) 
       call sgocls('DclDrawTickmark')
     end subroutine
-!---------------------------------- ʸǻꤷ٥
+!---------------------------------- 文字列で指定したラベルを描く
     subroutine DclDrawAxisLabel(side, position, label, sw)
-      character(len=*), intent(in)               :: side     !٥ɸξ
-      real,             intent(in), dimension(:) :: position !٥
-      character(len=*), intent(in), dimension(:) :: label    !٥
-      integer,          intent(in)               :: sw       !٥°
+      character(len=*), intent(in)               :: side     !ラベルを描く座標軸の場所
+      real,             intent(in), dimension(:) :: position !ラベルを描く場所
+      character(len=*), intent(in), dimension(:) :: label    !ラベル
+      integer,          intent(in)               :: sw       !ラベルの属性
       optional :: label, sw
 
       call sgoopn('DclDrawAxisLabel', ' ')
@@ -396,7 +396,7 @@ module uspack
       end if 
       call sgocls('DclDrawAxisLabel')
     end subroutine
-!---------------------------------- 򤺤餹
+!---------------------------------- 軸をずらす。
     subroutine DclShiftAxis(side)
       character(len=*), intent(in) :: side
 
