@@ -5,9 +5,9 @@ module uzpack
   use dcl_common
   contains
 
-!------------------------------ !ʸ礭򤹤٤Ʋܤ롥
+!------------------------------ !文字の大きさ等をすべて何倍かする．
     subroutine DclSetAxisFactor(fact)
-      real,      intent(in) :: fact       !Ψ
+      real,      intent(in) :: fact       !倍率
 
       call prcopn('DclSetAxisFactor')
       call uzfact(fact) 
