@@ -74,7 +74,7 @@
       END IF
 
 *-- INITIALIZING GRID_NUM (COUNTER FOR PASSING STREAM LINES IN EACH GRID)
-*-- ʻ̲ήΥѿ
+*-- 格子点通過流線のカウンタ変数を初期化
       DO 11 J=1,NY
          DO 10 I=1,NX
             GRID_NUM(I,J)=0
@@ -87,8 +87,8 @@
       DICOUNTER=1
 
 *-- DETERMINING "DT" (DT=DXMIN/VMAX)
-*-- ʲή׻κݤʬˤ
-*-- CFL Τ褦ʤΤꤹ.
+*-- 以下で流線計算の際の積分における
+*-- CFL 条件のようなものを決定する.
 **      MAXV=0.0
 
 **      DO 31 J=1,NY
@@ -168,27 +168,27 @@
       WRITE(RCHARC(1:10),'(1P,E10.3)') DT
       CALL MSGDMP( 'M', 'TMSTLN', 'DT          ===> '//RCHARC(1:10) ) 
 
-*-- ʾε CFL 狼ʬƥåפ.
+*-- 以上の擬似 CFL 条件から時間積分ステップを決める.
 **      DT=MINR/MAXV
 
 *-- STARTING TO CALCULATE STREAM LINES.
 *-- DETERMINING STARTING POINT BY USING A PARAMETER VALUE "SKIP".
 
-*-- [1] ΰ趭Ȥή׻Ԥ
-*-- ʲη׻ [2]  61, 60 롼פΰۤʤΤߤ,
-*-- 롼νƱǤ.
-*-- 161  X , 261  Y Ȥ.
+*-- [1] 領域境界上を始点として流線計算を行う
+*-- 以下の計算は [2] の 61, 60 ループの引数が異なるのみで,
+*-- ループ内部の処理は全く同じである.
+*-- 161 は X 軸境界, 261 は Y 軸境界を始点とする.
       DO 161 JD=1,2
          J=NYBOUND(JD)
          IF(MOD((J-1),SKIP).EQ.0.OR.J.EQ.NY)THEN
             DO 160 I=1,NX
                IF(MOD((I-1),SKIP).EQ.0.OR.I.EQ.NX)THEN
-                  IF(U(I,J).NE.0.0.OR.V(I,J).NE.0.0)THEN  !* ʻ®ʤ TMSLCL ʤ.
+                  IF(U(I,J).NE.0.0.OR.V(I,J).NE.0.0)THEN  !* 格子点上で風速がゼロなら TMSLCL に入らない.
                      TMPRX(1,1)=X(I)
                      TMPRY(1,1)=Y(J)
                      TMPCOUNTER=COUNTER
                      IF(GRID_NUM(I,J).LE.THRES)THEN
-                        DO 162 K=TMPCOUNTER,NX*NY  !* ͤϼꤹʵ⤹.
+                        DO 162 K=TMPCOUNTER,NX*NY  !* この閾値は取りすぎな気もする.
                            CALL TMRSET( 'STLNDT', ABS(DT) )
                            CALL TMSLCL( TMPRX(1,1), TMPRY(1,1),
      &                                  NX, NY, X, Y, U, V,
@@ -196,7 +196,7 @@
      &                                  NM(COUNTER,1), GRID_NUM )
                            COUNTER=COUNTER+1
 
-                           !* ֥롼֤ͤͤ.
+                           !* サブルーチンの返り値へ値を入れる.
                            IF(NM(COUNTER-1,1).GT.1)THEN
                              IF(DCOUNTER.GT.1)THEN
                                TOTNM(DCOUNTER,1)=TOTNM(DCOUNTER-1,1)
@@ -213,9 +213,9 @@
                              DCOUNTER=DCOUNTER+1
                            END IF
 
-*-- ήѰդʾϢ³, ǽޤǷ׻.
+*-- 流線が用意した配列以上に連続する場合, ここで終わるまで計算させる.
                            IF(NM(COUNTER-1,1).LT.NX*NY)THEN
-                              IF(PFX.EQV..TRUE.)THEN  !* äƤ, ʤ鶭夬Ǥεշ׻, Ǥʤмή׻.
+                              IF(PFX.EQV..TRUE.)THEN  !* 終わっていれば, 周期境界なら境界上が開始点での逆計算へ, 周期境界でなければ次の流線計算へ.
                                 IF(I.EQ.1.OR.I.EQ.NX)THEN
                                    GO TO 163
                                 ELSE
@@ -232,9 +232,9 @@
                                    GO TO 160
                                 END IF
                               ELSE
-                                 GO TO 163  !* äƤеո׻.
+                                 GO TO 163  !* 終わっていれば逆向き計算へ.
                               END IF
-                           ELSE  !* Ѱդۤή³ΰѤ
+                           ELSE  !* 用意した配列を越えて流線が続く場合の引き継ぎ
                               TMPRX(1,1)=TMPRX(NX*NY,1)
                               TMPRY(1,1)=TMPRY(NX*NY,1)
                            END IF
@@ -256,9 +256,9 @@
 *-- CALCULATING INVERSE DIRECTION.
 *-- "TMSLCL" CAN CALCULATE FORWARD DIRECTION FOR "DT>0",
 *-- BACKWARD DIRECTION FOR "DT<0".
-*-- ήΰǳϤƤΤ, ոˤ׻.
-*-- DT ĤƵõ.
-*-- GRID_NUM(I,J) ׻ǥȤƤΤ, ΥȤ򳰤Ƥ
+*-- 流線が領域内で開始されているので, 逆向きにも計算する.
+*-- DT に負号をつけて逆探査開始.
+*-- GRID_NUM(I,J) は前方計算でカウントされているので, このカウントを外しておく
  163                    IF(ICOUNTER.LT.NX*NY)THEN
                            GRID_NUM(I,J)=GRID_NUM(I,J)-1
                            TMPRX(1,2)=X(I)
@@ -272,22 +272,22 @@
                         TMPCOUNTER=ICOUNTER
 
                         DO 164 K=TMPCOUNTER,NX*NY
-                           CALL TMRSET( 'STLNDT', -ABS(DT) )  ! ո׻Τ, Ĥ
+                           CALL TMRSET( 'STLNDT', -ABS(DT) )  ! 逆向き計算のため, 負号つき
                            CALL TMSLCL( TMPRX(1,2), 
      &                                  TMPRY(1,2),
      &                                  NX, NY, X, Y, U, V, 
      &                                  TMPX(:), TMPY(:),
      &                                  NM(ICOUNTER,2), GRID_NUM )
 
-*-- շ׻ʬ TRX, TRY ˳Ǽ.
-*-- , ո׻ʤΤ, ϵդ.
+*-- 逆計算分を TRX, TRY に格納.
+*-- ただし, 逆向き計算なので, 配列は逆から入れる.
                            IF(NM(ICOUNTER,2).GT.1)THEN
                               DO 170 L=1,NM(ICOUNTER,2)
                                  TMPRX(L,2)=TMPX(NM(ICOUNTER,2)-L+1)
                                  TMPRY(L,2)=TMPY(NM(ICOUNTER,2)-L+1)
  170                          CONTINUE
 
-                              !* ֥롼֤ͤͤ.
+                              !* サブルーチンの返り値へ値を入れる.
                               IF(DICOUNTER.GT.1)THEN
                                 TOTNM(DICOUNTER,2)=TOTNM(DICOUNTER-1,2)
      &                                             +NM(ICOUNTER,2)
@@ -304,10 +304,10 @@
                            END IF
                            ICOUNTER=ICOUNTER+1
 
-*-- ήѰդʾϢ³, ǽޤǷ׻.
+*-- 流線が用意した配列以上に連続する場合, ここで終わるまで計算させる.
                            IF(NM(ICOUNTER-1,2).LT.NX*NY)THEN
-                              GO TO 160  !* äƤмή׻
-                           ELSE  !* Ѱդۤή³ΰѤ
+                              GO TO 160  !* 終わっていれば次の流線計算へ
+                           ELSE  !* 用意した配列を越えて流線が続く場合の引き継ぎ
                               TMPRX(1,2)=TMPX(NX*NY)
                               TMPRY(1,2)=TMPY(NX*NY)
                            END IF
@@ -334,15 +334,15 @@
 
       DO 261 JD=1,2
          I=NXBOUND(JD)
-         DO 260 J=2,NY-1  ! üΰϾΥ롼פǹԤäƤ.
+         DO 260 J=2,NY-1  ! 端領域は上のループで行っている.
             IF(MOD((J-1),SKIP).EQ.0.OR.J.EQ.NY)THEN
                IF(MOD((I-1),SKIP).EQ.0.OR.I.EQ.NX)THEN
-                  IF(U(I,J).NE.0.0.OR.V(I,J).NE.0.0)THEN  !* ʻ®ʤ TMSLCL ʤ.
+                  IF(U(I,J).NE.0.0.OR.V(I,J).NE.0.0)THEN  !* 格子点上で風速がゼロなら TMSLCL に入らない.
                      TMPRX(1,1)=X(I)
                      TMPRY(1,1)=Y(J)
                      TMPCOUNTER=COUNTER
                      IF(GRID_NUM(I,J).LE.THRES)THEN
-                        DO 262 K=TMPCOUNTER,NX*NY  !* ͤϼꤹʵ⤹.
+                        DO 262 K=TMPCOUNTER,NX*NY  !* この閾値は取りすぎな気もする.
                            CALL TMRSET( 'STLNDT', ABS(DT) )
                            CALL TMSLCL( TMPRX(1,1), TMPRY(1,1),
      &                                  NX, NY, X, Y, U, V,
@@ -350,7 +350,7 @@
      &                                  NM(COUNTER,1), GRID_NUM )
                            COUNTER=COUNTER+1
 
-                           !* ֥롼֤ͤͤ.
+                           !* サブルーチンの返り値へ値を入れる.
                            IF(NM(COUNTER-1,1).GT.1)THEN
                              IF(DCOUNTER.GT.1)THEN
                                TOTNM(DCOUNTER,1)=TOTNM(DCOUNTER-1,1)
@@ -367,9 +367,9 @@
                              DCOUNTER=DCOUNTER+1
                            END IF
 
-*-- ήѰդʾϢ³, ǽޤǷ׻.
+*-- 流線が用意した配列以上に連続する場合, ここで終わるまで計算させる.
                            IF(NM(COUNTER-1,1).LT.NX*NY)THEN
-                              IF(PFX.EQV..TRUE.)THEN !* äƤ, ʤ鶭夬Ǥεշ׻, Ǥʤмή׻.
+                              IF(PFX.EQV..TRUE.)THEN !* 終わっていれば, 周期境界なら境界上が開始点での逆計算へ, 周期境界でなければ次の流線計算へ.
                                 IF(I.EQ.1.OR.I.EQ.NX)THEN
                                    GO TO 263
                                 ELSE
@@ -386,9 +386,9 @@
                                    GO TO 260
                                 END IF
                               ELSE
-                                 GO TO 263  !* äƤеո׻.
+                                 GO TO 263  !* 終わっていれば逆向き計算へ.
                               END IF
-                           ELSE  !* Ѱդۤή³ΰѤ
+                           ELSE  !* 用意した配列を越えて流線が続く場合の引き継ぎ
                               TMPRX(1,1)=TMPRX(NX*NY,1)
                               TMPRY(1,1)=TMPRY(NX*NY,1)
                            END IF
@@ -410,9 +410,9 @@
 *-- CALCULATING INVERSE DIRECTION.
 *-- "TMSLCL" CAN CALCULATE FORWARD DIRECTION FOR "DT>0",
 *-- BACKWARD DIRECTION FOR "DT<0".
-*-- ήΰǳϤƤΤ, ոˤ׻.
-*-- DT ĤƵõ.
-*-- GRID_NUM(I,J) ׻ǥȤƤΤ, ΥȤ򳰤Ƥ
+*-- 流線が領域内で開始されているので, 逆向きにも計算する.
+*-- DT に負号をつけて逆探査開始.
+*-- GRID_NUM(I,J) は前方計算でカウントされているので, このカウントを外しておく
  263                    IF(ICOUNTER.LT.NX*NY)THEN
                            GRID_NUM(I,J)=GRID_NUM(I,J)-1
                            TMPRX(1,2)=X(I)
@@ -426,22 +426,22 @@
                         TMPCOUNTER=ICOUNTER
 
                         DO 264 K=TMPCOUNTER,NX*NY
-                           CALL TMRSET( 'STLNDT', -ABS(DT) )  ! ո׻Τ, Ĥ
+                           CALL TMRSET( 'STLNDT', -ABS(DT) )  ! 逆向き計算のため, 負号つき
                            CALL TMSLCL( TMPRX(1,2), 
      &                                  TMPRY(1,2),
      &                                  NX, NY, X, Y, U, V, 
      &                                  TMPX(:), TMPY(:),
      &                                  NM(ICOUNTER,2), GRID_NUM )
 
-*-- շ׻ʬ TRX, TRY ˳Ǽ.
-*-- , ո׻ʤΤ, ϵդ.
+*-- 逆計算分を TRX, TRY に格納.
+*-- ただし, 逆向き計算なので, 配列は逆から入れる.
                            IF(NM(ICOUNTER,2).GT.1)THEN
                               DO 270 L=1,NM(ICOUNTER,2)
                                  TMPRX(L,2)=TMPX(NM(ICOUNTER,2)-L+1)
                                  TMPRY(L,2)=TMPY(NM(ICOUNTER,2)-L+1)
  270                          CONTINUE
 
-                              !* ֥롼֤ͤͤ.
+                              !* サブルーチンの返り値へ値を入れる.
                               IF(DICOUNTER.GT.1)THEN
                                 TOTNM(DICOUNTER,2)=TOTNM(DICOUNTER-1,2)
      &                                             +NM(ICOUNTER,2)
@@ -458,10 +458,10 @@
                            END IF
                            ICOUNTER=ICOUNTER+1
 
-*-- ήѰդʾϢ³, ǽޤǷ׻.
+*-- 流線が用意した配列以上に連続する場合, ここで終わるまで計算させる.
                            IF(NM(ICOUNTER-1,2).LT.NX*NY)THEN
-                              GO TO 260  !* äƤмή׻
-                           ELSE  !* Ѱդۤή³ΰѤ
+                              GO TO 260  !* 終わっていれば次の流線計算へ
+                           ELSE  !* 用意した配列を越えて流線が続く場合の引き継ぎ
                               TMPRX(1,2)=TMPX(NX*NY)
                               TMPRY(1,2)=TMPY(NX*NY)
                            END IF
@@ -486,19 +486,19 @@
       COUNTER=COUNTER+1
       ICOUNTER=ICOUNTER+1
 
-*-- [2] ΰζή׻Ԥ.
-*-- GRID_NUM ˤä, ̲ᤷƤʤʻҤϸƤΤ, 
-*-- γʻҤˤĤ SKIP ֳ֤ή׻Ԥ.
+*-- [2] 領域内部の空白域で流線計算を行う.
+*-- GRID_NUM によって, 通過していない格子は検索されているので, 
+*-- その格子について SKIP 間隔で流線計算を行う.
       DO 61 J=2,NY-1
          IF(MOD((J-1),SKIP).EQ.0.OR.J.EQ.NY)THEN
             DO 60 I=2,NX-1
                IF(MOD((I-1),SKIP).EQ.0.OR.I.EQ.NX)THEN
-                  IF(U(I,J).NE.0.0.OR.V(I,J).NE.0.0)THEN  !* ʻ®ʤ TMSLCL ʤ.
+                  IF(U(I,J).NE.0.0.OR.V(I,J).NE.0.0)THEN  !* 格子点上で風速がゼロなら TMSLCL に入らない.
                      TMPRX(1,1)=X(I)
                      TMPRY(1,1)=Y(J)
                      TMPCOUNTER=COUNTER
                      IF(GRID_NUM(I,J).LE.THRES)THEN
-                        DO 62 K=TMPCOUNTER,NX*NY  !* ͤϼꤹʵ⤹.
+                        DO 62 K=TMPCOUNTER,NX*NY  !* この閾値は取りすぎな気もする.
                            CALL TMRSET( 'STLNDT', ABS(DT) )
                            CALL TMSLCL( TMPRX(1,1), TMPRY(1,1),
      &                                  NX, NY, X, Y, U, V,
@@ -506,7 +506,7 @@
      &                                  NM(COUNTER,1), GRID_NUM )
                            COUNTER=COUNTER+1
 
-                           !* ֥롼֤ͤͤ.
+                           !* サブルーチンの返り値へ値を入れる.
                            IF(NM(COUNTER-1,1).GT.1)THEN
                              IF(DCOUNTER.GT.1)THEN
                                TOTNM(DCOUNTER,1)=TOTNM(DCOUNTER-1,1)
@@ -523,12 +523,12 @@
                              DCOUNTER=DCOUNTER+1
                            END IF
 
-*-- ήѰդʾϢ³, ǽޤǷ׻.
+*-- 流線が用意した配列以上に連続する場合, ここで終わるまで計算させる.
                            IF(NM(COUNTER-1,1).LT.NX*NY)THEN
                               IF(I.NE.1.AND.I.NE.NX.AND.
      &                           J.NE.1.AND.J.NE.NY)THEN
-                                 GO TO 63  !* äƤеշ׻ (ΰ¦) .
-                              ELSE  !* äƤ, ʤ鶭夬Ǥεշ׻, Ǥʤмή׻.
+                                 GO TO 63  !* 終わっていれば逆計算へ (開始点が領域内側) .
+                              ELSE  !* 終わっていれば, 周期境界なら境界上が開始点での逆計算へ, 周期境界でなければ次の流線計算へ.
                                  IF(PFX.EQV..TRUE.)THEN
                                    IF(I.EQ.1.OR.I.EQ.NX)THEN
                                       GO TO 63
@@ -546,10 +546,10 @@
                                       GO TO 60
                                    END IF
                                  ELSE
-                                    GO TO 60  !* äƤмή׻ (ΰ趭)
+                                    GO TO 60  !* 終わっていれば次の流線計算へ (開始点が領域境界)
                                  END IF
                               END IF
-                           ELSE  !* Ѱդۤή³ΰѤ
+                           ELSE  !* 用意した配列を越えて流線が続く場合の引き継ぎ
                               TMPRX(1,2)=TMPX(NX*NY)
                               TMPRY(1,2)=TMPY(NX*NY)
                            END IF
@@ -571,9 +571,9 @@
 *-- CALCULATING INVERSE DIRECTION.
 *-- "TMSLCL" CAN CALCULATE FORWARD DIRECTION FOR "DT>0",
 *-- BACKWARD DIRECTION FOR "DT<0".
-*-- ήΰǳϤƤΤ, ոˤ׻.
-*-- DT ĤƵõ.
-*-- GRID_NUM(I,J) ׻ǥȤƤΤ, ΥȤ򳰤Ƥ
+*-- 流線が領域内で開始されているので, 逆向きにも計算する.
+*-- DT に負号をつけて逆探査開始.
+*-- GRID_NUM(I,J) は前方計算でカウントされているので, このカウントを外しておく
  63                     IF(ICOUNTER.LT.NX*NY)THEN
                            GRID_NUM(I,J)=GRID_NUM(I,J)-1
                            TMPRX(1,2)=X(I)
@@ -587,21 +587,21 @@
                         TMPCOUNTER=ICOUNTER
 
                         DO 64 K=TMPCOUNTER,NX*NY
-                           CALL TMRSET( 'STLNDT', -ABS(DT) )  ! ո׻Τ, Ĥ
+                           CALL TMRSET( 'STLNDT', -ABS(DT) )  ! 逆向き計算のため, 負号つき
                            CALL TMSLCL( TMPRX(1,2), TMPRY(1,2),
      &                                  NX, NY, X, Y, U, V, 
      &                                  TMPX(:), TMPY(:),
      &                                  NM(ICOUNTER,2), GRID_NUM )
 
-*-- շ׻ʬ TRX, TRY ˳Ǽ.
-*-- , ո׻ʤΤ, ϵդ.
+*-- 逆計算分を TRX, TRY に格納.
+*-- ただし, 逆向き計算なので, 配列は逆から入れる.
                            IF(NM(ICOUNTER,2).GT.1)THEN
                               DO 70 L=1,NM(ICOUNTER,2)
                                  TMPRX(L,2)=TMPX(NM(ICOUNTER,2)-L+1)
                                  TMPRY(L,2)=TMPY(NM(ICOUNTER,2)-L+1)
  70                           CONTINUE
 
-                              !* ֥롼֤ͤͤ.
+                              !* サブルーチンの返り値へ値を入れる.
                               IF(DICOUNTER.GT.1)THEN
                                 TOTNM(DICOUNTER,2)=TOTNM(DICOUNTER-1,2)
      &                                             +NM(ICOUNTER,2)
@@ -618,10 +618,10 @@
                            END IF
                            ICOUNTER=ICOUNTER+1
 
-*-- ήѰդʾϢ³, ǽޤǷ׻.
+*-- 流線が用意した配列以上に連続する場合, ここで終わるまで計算させる.
                            IF(NM(ICOUNTER-1,2).LT.NX*NY)THEN
-                              GO TO 60  !* äƤмή׻
-                           ELSE  !* Ѱդۤή³ΰѤ
+                              GO TO 60  !* 終わっていれば次の流線計算へ
+                           ELSE  !* 用意した配列を越えて流線が続く場合の引き継ぎ
                               TMPRX(1,2)=TMPX(NX*NY)
                               TMPRY(1,2)=TMPY(NX*NY)
                            END IF
